summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopeteawayaction.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:14:03 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:14:03 -0600
commit9c9412b30c54468adc9e506cc76c5d113fbf5056 (patch)
tree68a0c0d5bc770fc58596b8c5624cdf33d8625027 /kopete/libkopete/kopeteawayaction.h
parent2e53bd0b77676f879fad7baeecea5879bf496a7d (diff)
downloadtdenetwork-9c9412b30c54468adc9e506cc76c5d113fbf5056.tar.gz
tdenetwork-9c9412b30c54468adc9e506cc76c5d113fbf5056.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'kopete/libkopete/kopeteawayaction.h')
-rw-r--r--kopete/libkopete/kopeteawayaction.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kopete/libkopete/kopeteawayaction.h b/kopete/libkopete/kopeteawayaction.h
index 23680ed4..805d6c89 100644
--- a/kopete/libkopete/kopeteawayaction.h
+++ b/kopete/libkopete/kopeteawayaction.h
@@ -32,12 +32,12 @@ class OnlineStatus;
/**
* @class Kopete::AwayAction
*
- * Kopete::AwayAction is a KAction that lets you select an away message
+ * Kopete::AwayAction is a TDEAction that lets you select an away message
* from the list of predefined away messages, or enter a custom one.
*
* @author Jason Keirstead <jason@keirstead.org>
*/
-class KOPETE_EXPORT AwayAction : public KSelectAction
+class KOPETE_EXPORT AwayAction : public TDESelectAction
{
Q_OBJECT
@@ -45,10 +45,10 @@ class KOPETE_EXPORT AwayAction : public KSelectAction
/**
* Constructor
* @p text, @p pix, @p cut, @p receiver, @p slot, @p parent and
* @p name are all handled by KSelectAction.
**/
AwayAction(const TQString &text, const TQIconSet &pix,
- const KShortcut &cut, const TQObject *receiver, const char *slot,
+ const TDEShortcut &cut, const TQObject *receiver, const char *slot,
TQObject *parent, const char *name = 0);
/**
@@ -56,10 +56,10 @@ class KOPETE_EXPORT AwayAction : public KSelectAction
* @param status the OnlineStatus that appears in the signal
* @param slot must have the following signature: ( const OnlineStatus &, const TQString & )
* @p text, @p pix, @p cut, @p receiver, @p slot, @p parent and
* @p name are all handled by KSelectAction.
**/
AwayAction(const OnlineStatus &status, const TQString &text, const TQIconSet &pix,
- const KShortcut &cut, const TQObject *receiver, const char *slot,
+ const TDEShortcut &cut, const TQObject *receiver, const char *slot,
TQObject *parent, const char *name = 0);
/**
@@ -45,10 +45,10 @@ class KOPETE_EXPORT AwayAction : public KSelectAction
* Constructor
* @p text, @p pix, @p cut, @p receiver, @p slot, @p parent and
- * @p name are all handled by KSelectAction.
+ * @p name are all handled by TDESelectAction.
**/
AwayAction(const TQString &text, const TQIconSet &pix,
@@ -56,10 +56,10 @@ class KOPETE_EXPORT AwayAction : public KSelectAction
* @param slot must have the following signature: ( const OnlineStatus &, const TQString & )
* @p text, @p pix, @p cut, @p receiver, @p slot, @p parent and
- * @p name are all handled by KSelectAction.
+ * @p name are all handled by TDESelectAction.
**/
AwayAction(const OnlineStatus &status, const TQString &text, const TQIconSet &pix,